#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define name_ext -test
%bcond_without test
%else
%define name_ext %{nil}
%bcond_with test
%endif
%define _name   mesonbuild
%{!?vim_data_dir:%global vim_data_dir %{_datadir}/vim}
%bcond_with     setuptools
Name:           meson%{name_ext}
Version:        0.61.4
Release:        150500.1.7
Summary:        Python-based build system
License:        Apache-2.0
Group:          Development/Tools/Building
URL:            https://mesonbuild.com/
Source:         https://github.com/%{_name}/meson/releases/download/%{version}/meson-%{version}.tar.gz
Source1:        https://github.com/%{_name}/meson/releases/download/%{version}/meson-%{version}.tar.gz.asc
Source2:        meson.keyring
# PATCH-FIX-UPSTREAM 34daa53a.patch dimstar@opensuse.org -- gnome module: properly fallback to gtk-update-icon-cache
Patch0:         https://github.com/mesonbuild/meson/commit/34daa53a.patch
# PATCH-FIX-OPENSUSE meson-test-installed-bin.patch dimstar@opensuse.org -- We want the test suite to run against /usr/bin/meson coming from our meson package.
Patch1:         meson-test-installed-bin.patch
# PATCH-FEATURE-OPENSUSE meson-distutils.patch tchvatal@suse.com -- build and install using distutils instead of full setuptools
Patch2:         meson-distutils.patch
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-base
%if "%{flavor}" != "test"
BuildArch:      noarch
%endif
%if %{with setuptools}
BuildRequires:  python3-setuptools
Requires:       python3-setuptools
%endif
%if !%{with test}
Requires:       ninja >= 1.7
Requires:       python3-base
# meson-gui was last used in openSUSE Leap 42.1.
Provides:       meson-gui = %{version}
Obsoletes:      meson-gui < %{version}
%else
BuildRequires:  bison
BuildRequires:  clang
BuildRequires:  cups-devel
BuildRequires:  distribution-release
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gcc-obj-c++
BuildRequires:  gcc-objc
%if 0%{?sle_version} >= 150400
BuildRequires:  libstdc++6-devel-gcc11
%endif
BuildRequires:  gettext
BuildRequires:  git
BuildRequires:  gmock
BuildRequires:  gnustep-make
BuildRequires:  googletest-devel
BuildRequires:  itstool
BuildRequires:  libjpeg-devel
BuildRequires:  libpcap-devel
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  libqt5-qtbase-private-headers-devel
BuildRequires:  libwmf-devel
BuildRequires:  llvm-devel
BuildRequires:  meson = %{version}
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  python3-gobject
BuildRequires:  python3-pytest-xdist
BuildRequires:  zlib-devel-static
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(python3) >= 3.5
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vapigen)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} <= 1500
BuildRequires:  python2-PyYAML
%endif
%if 0%{?suse_version} < 1550
BuildRequires:  python2-devel
%endif
%if 0%{?suse_version} >= 1500
BuildRequires:  java-headless
BuildRequires:  libboost_log-devel
BuildRequires:  libboost_python3-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  rust
BuildRequires:  wxWidgets-any-devel
%if 0%{?suse_version} < 1550
BuildRequires:  libboost_python-devel
%endif
# csharp is not on s390 machines
%ifnarch s390x
BuildRequires:  mono(csharp)
%endif
%else
BuildRequires:  boost-devel
BuildRequires:  mono-core
BuildRequires:  wxWidgets-devel
%endif
%endif
# meson makes use of macros that were only defined with rpm 4.15
%if (0%{?suse_version} < 1550 && 0%{?sle_version} < 150400)
Conflicts:      rpm-build < 4.15
%endif

%description
Meson is a build system designed to optimise programmer productivity.
It aims to do this by providing support for software development
tools and practices, such as unit tests, coverage reports, Valgrind,
CCache and the like. Supported languages include C, C++, Fortran,
Java, Rust. Build definitions are written in a non-turing complete
Domain Specific Language.

%package vim
Summary:        Vim support for meson.build files
Group:          Productivity/Text/Editors
Requires:       vim
Supplements:    (vim and %{name})
BuildArch:      noarch

%description vim
Meson is a build system designed to optimise programmer productivity.
It aims to do this by providing support for software development
tools and practices, such as unit tests, coverage reports, Valgrind,
CCache and the like. Supported languages include C, C++, Fortran,
Java, Rust. Build definitions are written in a non-turing complete
Domain Specific Language.

This package provides support for meson.build files in Vim.

%prep
%setup -q -n meson-%{version}
%patch0 -p1
%patch1 -p1
%if !%{with setuptools}
%patch2 -p1
%endif

# We do not have appleframeworks available at this moment - can't run the test suite for it
# boost is currently borked too
rm -r "test cases/frameworks/1 boost" \
      "test cases/objc/2 nsstring"

# AddressSanitizer fails here because of ulimit.
sed -i "/def test_generate_gir_with_address_sanitizer/s/$/\n        raise unittest.SkipTest('ulimit')/" run_unittests.py

# Remove hashbang from non-exec script
sed -i '1{/\/usr\/bin\/env/d;}' ./mesonbuild/rewriter.py

# remove gtest check that actually works because our gtest has .pc files
rm -rf test\ cases/failing/85\ gtest\ dependency\ with\ version

%build
%if !%{with test}
%python3_build
%else
# Ensure we have no mesonbuild / meson in CWD, thus guaranteeing we use meson in $PATH
rm -r meson.py mesonbuild
%endif

%install
# If this is the test suite, we don't need anything else but the meson package
%if !%{with test}
%python3_install
%fdupes %{buildroot}%{python3_sitelib}

install -Dpm 0644 data/macros.meson \
  %{buildroot}%{_rpmconfigdir}/macros.d/macros.meson

install -Dpm 0644 data/syntax-highlighting/vim/ftdetect/meson.vim \
  -t %{buildroot}%{vim_data_dir}/site/ftdetect/
install -Dpm 0644 data/syntax-highlighting/vim/indent/meson.vim \
  -t %{buildroot}%{vim_data_dir}/site/indent/
install -Dpm 0644 data/syntax-highlighting/vim/syntax/meson.vim \
  -t %{buildroot}%{vim_data_dir}/site/syntax/

# entry points are not distutils-able
%if !%{with setuptools}
mkdir -p %{buildroot}%{_bindir}
echo """#!%{_bindir}/python3
import sys

from mesonbuild.mesonmain import main
sys.exit(main())
""" > %{buildroot}%{_bindir}/%{name}
chmod +x %{buildroot}%{_bindir}/%{name}

# ensure egg-info is a directory
rm %{buildroot}%{python3_sitelib}/*.egg-info
cp -r meson.egg-info %{buildroot}%{python3_sitelib}/meson-%{version}-py%{python3_version}.egg-info
%endif
%endif

%if %{with test}
%check
export LANG=C.UTF-8
export MESON_EXE=%{_bindir}/meson
python3 run_tests.py --failfast
%endif

%files
%license COPYING
%if !%{with test}
%{_bindir}/meson
%{python3_sitelib}/%{_name}/
%{python3_sitelib}/meson-*
%dir %{_datadir}/polkit-1/
%dir %{_datadir}/polkit-1/actions/
%{_datadir}/polkit-1/actions/com.mesonbuild.install.policy
%{_rpmconfigdir}/macros.d/macros.meson
%{_mandir}/man1/meson.1%{?ext_man}

%files vim
%doc data/syntax-highlighting/vim/README
%dir %{vim_data_dir}/
%dir %{vim_data_dir}/site/
%dir %{vim_data_dir}/site/ftdetect/
%dir %{vim_data_dir}/site/indent/
%dir %{vim_data_dir}/site/syntax/
%{vim_data_dir}/site/ftdetect/meson.vim
%{vim_data_dir}/site/indent/meson.vim
%{vim_data_dir}/site/syntax/meson.vim
%endif

%changelog
* Mon Jan 16 2023 yfjiang@suse.com
- Add BuildRequires libstdc++6-devel-gcc11 for SLE 15 SP4 and
  version above, which is necessary to make clang-tiny unit test
  run.
* Mon Apr 25 2022 dimstar@opensuse.org
- Add 34daa53a.patch: gnome module: properly fallback to
  gtk-update-icon-cache.
* Sat Apr 23 2022 rpm@fthiessen.de
- Update to 0.61.4:
  * Fixes for the ninja backend
  * Fixes for the rust module
  * Fixes for the gnome module: Fix incorrect lookup of nonexistent
    dependencies
* Tue Mar 15 2022 andreas.stieger@gmx.de
- update to 0.61.3:
  * fixes for other platform
  * test updates and developer visible fixes
* Tue Feb 15 2022 info@paolostivanin.com
- Update to 0.61.2:
  + No changelog provided.
* Sat Feb  5 2022 andreas.stieger@gmx.de
- update to 0.61.1:
  * add a man page backend to refman
  * extract_objects() supports generated sources
  * Python 3.6 support is deprecated
  * Warning if check kwarg of run_command is missing
  * meson rewrite can modify extra_files
  * meson rewrite target <target> info output target's extra_files
  * Support for CMake <3.15 is now deprecated for CMake subprojects
  * Add support for sccache
  * Add install_symlink function
* Tue Dec 28 2021 dimstar@opensuse.org
- Update to version 0.60.3:
  + gnome module: fix install_dir x3, by allowing false *_gir and
  * _typelib.
  + iconv dependency: try even harder to find working iconv.
  + Fix performance regression in build file generation.
  + add ft32 cpu family.
  + restore the ability in the backend to silently find a program.
  + pkgconfig: Fix linking to a custom target.
- Drop 3074bb14a14c00aeb350bf592acf635a93b52d9a.patch: fixed
  upstream.
* Tue Dec 14 2021 bjorn.lie@gmail.com
- Update to version 0.60.2:
  + Fix version requirement on Ninja feature
  + Fix custom_target with install: true and no install_dir,
    crashing
  + Fix regression that broke string.format with list objects
  + valac dependencies: use the canonical list of vala source names
  + interpreter: disallow RunTarget in meson.add_install_script
  + Only pass clang LTO arguments when they are needed
  + Support ancient (<3.4.0) gcc versions
  + Only exclude _bootlocale with Python >= 3.10
  + cmake: Use find_library() on bare library names in cmake
    dependencies
  + dependencies/zlib: Allow for generic OS checks
  + rust: clean up inputs and outputs to bindgen
  + interpreter: extract_objects provides a valid source
  + build|backend: Fix some type annotations
  + backends/backends: recurse when looking for paths in bundled
    shared libs
  + shared_module: Add soname when used as a link target
  + iconv dependency: include header when checking for libc builtin
- Drop unused python3-setuptools BuildRequires.
- Add 3074bb14a14c00aeb350bf592acf635a93b52d9a.patch: gnome module:
  fix install_dir x3, by allowing false *_gir and *_typelib.
* Wed Nov  3 2021 bjorn.lie@gmail.com
- Update to version 0.60.1:
  + No upstream changes provided.
- Changes from version 0.60.0:
  + run_target can now be used as a dependency.
  + The Python Modules dependency method no longer accepts
    positional arguments.
  + Override python installation paths.
  + New subprojects packagefiles subcommand.
  + Project options declared in meson_options.txt can now be marked
    as deprecated.
  + More efficient static linking of uninstalled libraries.
  + Cython can now transpile to C++ as an intermediate language.
  + Unknown options are now always fatal.
  + Install DESTDIR relative to build directory.
  + Improvements for the Rustc compiler.
  + Waf support in external-project module.
  + Dependencies with multiple names.
- Add gmock BuildRequires and stop deleting gmock testfiles, run
  the test suite for it.
- Update Supplements to current standard.
* Sun Oct 31 2021 andreas.stieger@gmx.de
- meson 0.59.4:
  * Fix crash when getting cuda options
* Mon Oct 25 2021 bjorn.lie@gmail.com
- Update to version 0.59.3:
  + No upstream changes provided.
- Drop meson-rust-1.55.patch: Fixed upstream.
* Wed Sep 29 2021 dimstar@opensuse.org
- Add meson-rust-1.55.patch: Fix test suite run with rust 1.55.
* Wed Sep 29 2021 dimstar@opensuse.org
- Update to version 0.59.2:
  + No upstream changes provided.
* Thu Aug 19 2021 bjorn.lie@gmail.com
- Update to version 0.59.1:
  + No upstream changes provided.
* Fri Aug  6 2021 mrueckert@suse.de
- Update to version 0.59.0:
  https://mesonbuild.com/Release-notes-for-0-59-0.html
- refreshed meson-test-installed-bin.patch to apply cleanly again
* Fri Jul 30 2021 fcrozat@suse.com
- Relax BuildRequires on rpm, if rpm-config-SUSE is recent enough
  (jsc#SLE-20017).
* Tue Jul 20 2021 dimstar@opensuse.org
- Update to version 0.58.2:
  + gnome: Always pass absolute -L paths to g-ir-scanner.
* Wed Jul 14 2021 dimstar@opensuse.org
- Update to version 0.58.1:
  + New meson.global_build_root() and meson.global_source_root()
    methods.
  + meson.add_dist_script() allowd in subprojects.
  + Do not add custom target dir to header path if
    implicit_include_directories is false.
  + Multiple append() and prepend() in environment() object.
  + clang-format include and ignore lists.
  + Introducing format strings to the Meson language.
  + Skip subprojects installation.
- Rebase meson-distutils.patch (work done by StevenK).
* Mon Jul 12 2021 dimstar@opensuse.org
- Update to version 0.57.2:
  + Support for reading files at configuration time with the fs
    module.
  + Experimental support for C++ modules in Visual Studio.
  + Qt6 module.
  + Minimum required Python version updated to 3.6.
  + New logging format for meson test.
  + Support added for LLVM's thinLTO.
- Drop 0200340a.patch: fixed upstream.
* Fri May  7 2021 dimstar@opensuse.org
- Add 0200340a.patch: gnome: Drop use of volatile in GLib type
  functions (boo#1185720).
* Thu Feb  4 2021 dimstar@opensuse.org
- Conflict with rpm-build < 4.15: meson uses internal macros
  defined by RPM 4.15 and later.
* Sat Jan 16 2021 bjorn.lie@gmail.com
- Update to version 0.56.2:
  + This release fixes a Python 3.5 compat issue.
* Thu Jan  7 2021 bjorn.lie@gmail.com
- Drop meson-suse-ify-macros.patch: No longer needed.
* Wed Jan  6 2021 dimstar@opensuse.org
- Update to version 0.56.1:
  + pkgconfig: Make external deps of static library public.
  + interpreter: store correct files for project regeneration.
  + environment: Properly pass linker to rustc.
  + Add aarch64 assembly test.
- Drop 7930.patch: fixed upstream.
- Add new keyid C24E631BABB1FE70 to the keyring (counter signed by
  the old key id): the old key was about to expire.
* Tue Nov 17 2020 guillaume.gardet@opensuse.org
- Remove "test cases/common/122 llvm ir and assembly" for aarch64
  as this test is not supported on aarch64 linux yet (boo1178772).
* Tue Nov  3 2020 dimstar@opensuse.org
- Add 7930.patch: pkgconfig: Make external deps of static library
  public.
* Fri Oct 30 2020 dimstar@opensuse.org
- Update to version 0.56.0:
  + meson test can now filter tests by subproject
  + Native (build machine) compilers not always required by
    project().
  + New extra_files key in target introspection.
  + meson.build_root() and meson.source_root() are deprecated.
  + dep.as_link_whole().
  + Added NVidia HPC SDK compilers.
  + CMake subproject cross compilation support.
  + Machine file keys are stored case sensitive.
  + Consistency between declare_dependency() and
    pkgconfig.generate() variables.
  + Qt5 compile_translations now supports qresource preprocessing.
  + Controlling subproject dependencies with
    dependency(allow_fallback: ...).
  + Improvements for the builtin curses dependency.
  + HDF5 dependency improvements.
  + Dependencies listed in test and benchmark introspection.
  + Deprecate Dependency.get_pkgconfig_variable and
    Dependency.get_configtool_variable.
- Rebase meson-test-installed-bin.patch.
* Fri Sep 11 2020 dimstar@opensuse.org
- Update to version 0.55.3:
  + Revert "msvc: enable /std:c11 flag".
- Changes from version 0.55.2:
  + msvc: enable /std:c11 flag.
  + environment: use ExternalProgram to find ninja.
  + CMake module: fix cmake 3.10 compatibility in path generation.
- Drop pr7648-fix-lchmod-check-for-glibc-2.32.patch: fixed
  upstream.
* Sat Aug 29 2020 callumjfarmer13@gmail.com
- Add pr7648-fix-lchmod-check-for-glibc-2.32.patch:
  fixes meson-test with glibc 2.32 (gh#mesonbuild/meson#7648)
* Mon Aug 17 2020 dimstar@opensuse.org
- Update to version 0.55.1:
  + find_library: Print type of library not found.
  + interpreter: Don't force fallback when subproject failed to
    configure.
  + Various fixes around cmake integration.
  + mdata: Generate mesondata.py from */data folders.
  + mdata: remove setuptools and use mesondata instead.
- Drop meson-pr7461-remove-setuptools-dependency.patch: fixed
  upstream.
* Sun Jul 26 2020 sor.alexei@meowr.ru
- Remove %%_smp_build_ncpus in meson-suse-ify-macros.patch.
- Drop broken meson-restore-python3.4.patch,
  meson-suse-fix-llvm-3.8.patch, meson-fix-gcc48.patch.
* Wed Jul 22 2020 callumjfarmer13@gmail.com
- Add meson-pr7461-remove-setuptools-dependency.patch: Fixes forced
  requirement on setuptools (gh#mesonbuild/meson#7461).
* Wed Jul 15 2020 callumjfarmer13@gmail.com
- Update to version 0.55.0
  + rpath removal now more careful
  + Added ability to specify targets in `meson compile`
  + Added test protocol for gtest
  + meson.add_*_script methods accept new types
  + Native and cross files now support string and list concatenation
  + Ability to configure CMake subprojects with meson.subproject_options
  + find_program: Fixes when the program has been overridden by executable
  + Response files enabled on Linux
  + `unstable-kconfig` module renamed to `unstable-keyval`
  + Config tool based dependencies no longer search PATH for cross compiling
  + String concatenation in meson_options.txt
  + Clang coverage support
  + Implicit dependency fallback
  + Added ability to specify backend arguments in `meson compile`
- Removed meson-fix-gnome-test.patch: contained in upstream
- Changed meson-suse-ify-macros.patch: to be compatible with new
  version
* Fri Jun 26 2020 mgorse@suse.com
- Add meson-fix-gnome-test.patch: fix GNOME test that sometimes
  fails (bsc#1173025).
* Tue Jun 16 2020 dimstar@opensuse.org
- Update to version 0.54.3:
  + Various fixes around cmake integration.
  + Various fixes around boost.
* Wed May 20 2020 mgorse@suse.com
- Make tests arch-dependent. Needed to exclude mono tests on s390x
  (bsc#1171934).
* Fri May 15 2020 dimstar@opensuse.org
- Update to version 0.54.2:
  + Various fixes around boost.
  + More robust cmake version detection.
  + Various GCC10 related fixes.
- Drop meson-gcc10.patch: fixed upstream.
* Thu May 14 2020 dimstar@opensuse.org
- Add meson-gcc10.patch: Fix test suite when using gcc 10.
* Wed May 13 2020 mgorse@suse.com
- Remove is_opensuse conditional and enable mono tests on SLE
  (jsc#SLE-11721).
* Mon Apr 27 2020 dimstar@opensuse.org
- Update to version 0.54.1:
  + compilers: Silence warning about gnu_inline with clang.
  + cmake: Do not compile explicit header files.
  + cmake: enhance support of cmake config file syntax.
  +  boost: Fix library version (fixes gh#mesonbuild/meeson#6899).
* Mon Mar 30 2020 dimstar@opensuse.org
- Update to version 0.54.0:
  + Emscripten (emcc) now supports threads.
  + Introduce dataonly for the pkgconfig module.
  + Consistently report file locations relative to cwd.
  + Native (build machine) compilers not always required.
  + Add a system type dependency for zlib.
  + New option --quiet to meson install.
  + Property support emscripten's wasm-ld.
  + Support for overiding the linker with ldc and gdc.
  + Per subproject default_library and werror options.
  + Ninja version requirement bumped to 1.7.
  + Added -C argument to meson init command.
  + CMake find_package COMPONENTS support.
  + Added Microchip XC16 C compiler support.
- Rebase meson-test-installed-bin.patch.
- Drop meson-testsuite-boost.patch: fixed (and enhanced) upstream.
- Drop meson-testsuite-boost2.patch: boost test suite globally
  disabled for now.
- Drop 6642.patch: Fixed in an alternative way.
- Remove hacks to drop static llvm and boost tests: fixed upstream.
* Thu Feb 27 2020 dimstar@opensuse.org
- Update to version 0.53.2:
  + Various cmake related issues fixed.
  + modules/python: Do not error out if positional args are passed.
- Drop meson-6614.patch: fixed upstream.
* Tue Feb 18 2020 mimi.vx@gmail.com
- Add 6642.patch - allow skip python2 unittests
    meson-testsuite-boost2.patch skip libboost_python tests on TW
* Wed Feb 12 2020 dimstar@opensuse.org
- Add meson-6614.patch: cmake: Fix crash when no C++ compiler is
  not installed (gh#mesonbuild/meson#6559).
* Tue Feb 11 2020 fcrozat@suse.com
- Add python2-PyYAML as BuildRequires for meson:test for SLE15.
* Fri Jan 24 2020 dimstar@opensuse.org
- Update to version 0.53.1:
  + Use python3 in some tests which were still using python.
  + test_pkgconfig_gen_deps: set
    PKG_CONFIG_SYSTEM_LIBRARY_PATH=/usr/lib. pkgconf automatically
    prunes "system library paths" from its output.
  + compilers: Derive CompilerArgs from collections instead of
    typing.
- Drop meson-pkgconf-libdir.patch: fixed upstream.
- Rebase meson-testsuite-boost.patch.
* Wed Jan  8 2020 dimstar@opensuse.org
- Update to version 0.53.0:
  + A new module for filesystem operations.
  + meson dist --include-subprojects.
  + Added new Meson templates for Dlang, Rust, Objective-C
  + Add a new summary() function
  + Generic Overrider for Dynamic Linker selection
  + fortran_std option
  + python.dependency() embed kwarg
  + Scalapack
  + Search directories for find_program()
  + Source tags targets
  + Dictionary entry using string variable as key
  + Improved CMake subprojects support
  + compiler.get_linker_id()
  + CUDA dependency
  + Added global option to disable C++ RTTI
  + Introspection API changes
- Add meson-testsuite-boost.patch: Fix detection of boost_python
  names. This is apparently inconsistent accross distros.
- Add meson-pkgconf-libdir.patch: pkgconf does not honor /usr/lib
  as 'system directory' on biarch systems.
* Sat Nov 30 2019 dimstar@opensuse.org
- Update to version 0.52.1:
  + linkers: Concatenate -L and the directory.
  + Remove duplicated object files in static libraries.
  + Revert "Add `-Wl,-rpath-link` for secondary dependencies".
- Drop meson-testsuite.patch: fixed upstream.
* Thu Oct 24 2019 fcrozat@suse.com
- Do not buildrequires rust-std, it is already required by rust.
* Mon Oct 21 2019 fcrozat@suse.com
- Do not buildrequires mono(csharp) or mono-core on SLE.
* Mon Oct  7 2019 dimstar@opensuse.org
- Update to version 0.52.0:
  + Gettext targets are ignored if gettext is not installed.
  + Support taking environment values from a dictionary.
  + Enhancements to the pkg_config_path argument.
  + The meson test program now accepts an additional "--gdb-path"
    argument to specify the GDB binary.
  + Splitting of Compiler.get_function_attribute('visibility').
  + Compiler and dynamic linker representation split.
  + Enhancements to the source_set module.
  + added --only test(s) option to run_project_tests.py.
  + Experimental Webassembly support via Emscripten.
  + Version check in find_program().
  + Improved support for static libraries.
  + Enhancements to the kconfig module.
  + Enhancements to configure_file().
  + Projects args can be set separately for build and host machines
    (potentially breaking change).
  + Dist is now a top level command.
- Rebase meson-test-installed-bin.patch and meson-distutils.patch.
- Drop gcc9-sanitizer.patch: no longer needed.
- Add meson-testsuite.patch: linkers: Concatenate -L and the
  directory.
* Tue Aug 27 2019 dimstar@opensuse.org
- Update to version 0.51.2:
  + gnome: Handle overriden g-ir-scanner.
  + cmake: fix missing -lpthread (fixes #5821)
  + Pass optimization flags to rustc properly. Closes: #5788.
- Drop fix-missing-return-statements-that-are-seen-with-Wer.patch:
  Fixed upstream.
* Tue Jul 16 2019 mliska@suse.cz
- Add fix-missing-return-statements-that-are-seen-with-Wer.patch which
  is an upstream version of: https://github.com/mesonbuild/meson/pull/5654
* Wed Jul 10 2019 dimstar@opensuse.org
- Update to version 0.51.1:
  + Increase logging for Rust CI failures.
  + tests/llvm: Test both cmake and llvm-config methods.
  + Improve error message when Python is not usable.
  + gnome.py: correctly pick the compiler for gtk-doc builds.
  + Switch to using Pyinstaller.
* Wed Jun 26 2019 dimstar@opensuse.org
- Update to versoin 0.51.0:
  + (C) Preprocessor flag handling.
  + Sanity checking compilers with user flags.
  + New sourceset module.
  + n_debug=if-release and buildtype=plain means no asserts.
  + target_type in build_targets accepts the value 'shared_module'.
  + New modules kwarg for python.find_installation.
  + Support for the Intel Compiler on Windows (ICL).
  + Added basic support for the Xtensa CPU toolchain.
  + Dependency objects now have a get_variable method.
  + CMake prefix path overrides.
  + Tests that should fail but did not are now errors.
  + New target keyword argument: link_language.
  + New module to parse kconfig output files.
  + Add new meson subprojects foreach command.
  + Added c17 and c18 as c_std values for recent GCC and Clang
    Versions.
  + gpgme dependency now supports gpgme-config.
  + Can link against custom targets.
  + Removed the deprecated --target-files API.
  + Generators have a new depends keyword argument.
  + Specifying options per mer machine.
  + subproject.get_variable() now accepts a fallback argument.
  + Add keyword static to find_library.
  + Fortran include statements recursively parsed.
  + CMake subprojects.
  + Multipe cross files can be specified.
- Rebase meson-suse-ify-macros.patch.
- Add python3-setuptools unconditionally to BuildRequires for the
  test suite.
* Thu May  2 2019 mliska@suse.cz
- Add gcc9-sanitizer.patch in order to handle unresolved symbols with
  - fsanitize=*. It's caused by sanitizer wrappers and our default --as-needed
  that we use as SUSE in our linker build (boo#1127953).
* Wed Apr 17 2019 dimstar@opensuse.org
- Update to version 0.50.1:
  + d: Fix linker errors with shared libraries.
  + Add support for VS2019 (gh#mesonbuild/meson#4640).
  + Detect 'arm64' as aarch64 CPU family.
  + Fix Rust global and local args (gh#mesonbuild/meson#5101).
* Mon Mar 11 2019 dimstar@opensuse.org
- Fixup meson-suse-ify-macros.patch post broken rebase.
* Sun Mar 10 2019 aloisio@gmx.com
- Update to version 0.50.0
  New features:
  * Added `cmake_module_path` and `cmake_args` to dependency
    The CMake dependency backend can now make use of existing
    `Find<name>.cmake` files by setting the `CMAKE_MODULE_PATH`
    with the new `dependency()` property `cmake_module_path`.
    The paths given to `cmake_module_path` should be relative
    to the project source directory.
    Furthermore the property `cmake_args` was added to give
    CMake additional parameters.
  * Added PGI compiler support
    Nvidia / PGI C, C++ and Fortran
    [no-cost](https://www.pgroup.com/products/community.htm)
    compilers are now supported. They have been tested on Linux
    so far.
  * Fortran Coarray
    Fortran 2008 / 2018 coarray support was added via
    `dependency('coarray')`
  * Libdir defaults to `lib` when cross compiling
    Previously `libdir` defaulted to the value of the build
    machine such as `lib/x86_64-linux-gnu`, which is almost
    always incorrect when cross compiling. It now defaults to
    plain `lib` when cross compiling. Native builds remain
    unchanged and will point to the current system's library
    dir.
  * Native and Cross File Paths and Directories
    A new `[paths]` section has been added to native and cross
    files. This can be used to set paths such a prefix and
    libdir in a persistent way.
  * Add warning_level 0 option
    Adds support for a warning level 0 which does not enable any
    static analysis checks from the compiler
  * A builtin target to run clang-format
    If you have `clang-format` installed and there is a
    `.clang-format` file in the root of your master project,
    Meson will generate a run target called `clang-format` so you
    can reformat all files with one command:
    ```meson
    ninja clang-format
    ```
  * Added a .path() method to object return by
    python.find_installation()
    `ExternalProgram` objects as well as the object returned by
    the `python3` module provide this method, but the new python
    module did not.
  * Fix ninja console log from generators with multiple output
    nodes
    This resolves ticket #4760 where a generator w/ multiple
    output nodes printed an empty string to the console
  * `introspect --buildoptions` can now be used without
    configured build directory
    It is now possible to run `meson introspect --buildoptions
    /path/to/meson.build` without a configured build directory.
    Running `--buildoptions` without a build directory produces
    the same output as running it with a freshly configured
    build directory.
    However, this behavior is not guaranteed if subprojects are
    present. Due to internal limitations all subprojects are
    processed even if they are never used in a real meson run.
    Because of this options for the subprojects can differ.
  * `include_directories` accepts a string
    The `include_directories` keyword argument now accepts plain
    strings rather than an include directory object. Meson will
    transparently expand it so that a declaration like this:
    ```meson
    executable(..., include_directories: 'foo')
    ```
    Is equivalent to this:
    ```meson
    foo_inc = include_directories('foo')
    executable(..., include_directories: inc)
    ```
  * Fortran submodule support
    Initial support for Fortran ``submodule`` was added, where
    the submodule is in the same or different file than the
    parent ``module``.
    The submodule hierarchy specified in the source Fortran code
    `submodule` statements are used by Meson to resolve source
    file dependencies.
    For example:
    ```fortran
    submodule (ancestor:parent) child
    ```
  * Add subproject_dir to --projectinfo introspection output
    This allows applications interfacing with Meson (such as
    IDEs) to know about an overridden subproject directory.
  * Find library with its headers
    The `find_library()` method can now also verify if the
    library's headers are found in a single call, using the
    `has_header()` method internally.
    ```meson
    + Aborts if the 'z' library is found but not its header file
    zlib = find_library('z', has_headers : 'zlib.h')
    + Returns not-found if the 'z' library is found but not its
    header file zlib = find_library('z', has_headers :
    'zlib.h', required : false)
    ```
    Any keyword argument with the `header_` prefix passed to
    `find_library()` will be passed to the `has_header()`
    method with the prefix removed.
    ```meson
    libfoo = find_library('foo',
    has_headers : ['foo.h', 'bar.h'],
    header_prefix : '#include <baz.h>',
    header_include_directories : include_directories('.'))
    ```
  * NetCDF
    NetCDF support for C, C++ and Fortran is added via
    pkg-config.
  * added the Flang compiler
    [Flang](https://github.com/flang-compiler/flang/releases)
    Fortran compiler support was added.  As with other Fortran
    compilers, flang is specified using `FC=flang meson ..` or
    similar.
  * New `not_found_message` for dependency
    You can now specify a `not_found_message` that will be
    printed if the specified dependency was not found. The point
    is to convert constructs
    that look like this:
    ```meson
    d = dependency('something', required: false)
    if not d.found()
    message('Will not be able to do something.')
    endif
    ```
    Into this:
    ```meson
    d = dependency('something',
    required: false,
    not_found_message: 'Will not be able to do something.')
    ```
    Or constructs like this:
    ```meson
    d = dependency('something', required: false)
    if not d.found()
    error('Install something by doing XYZ.')
    endif
    ```
    into this:
    ```meson
    d = dependency('something',
    not_found_message: 'Install something by doing XYZ.')
    ```
    Which works, because the default value of `required` is
    `true`.
  * Cuda support
    Compiling Cuda source code is now supported, though only
    with the
    Ninja backend. This has been tested only on Linux for now.
    Because NVidia's Cuda compiler does not produce `.d`
    dependency files, dependency tracking does not work.
  * `run_command` accepts `env` kwarg
    You can pass
    [`environment`](Reference-manual.html#environment-object)
    object to
    [`run_command`](Reference-manual.html#run-command), just
    like to `test`:
    ```meson
    env = environment()
    env.set('FOO', 'bar')
    run_command('command', 'arg1', 'arg2', env: env)
    ```
  * `extract_objects` accepts `File` arguments
    The `extract_objects` function now supports File objects to
    tell it what to extract. Previously, file paths could only
    be passed as strings.
  * Changed the JSON format of the introspection
    All paths used in the meson introspection JSON format are
    now absolute. This affects the `filename` key in the targets
    introspection and the output of
    `--buildsystem-files`.
    Furthermore, the `filename` and `install_filename` keys in
    the targets introspection are now lists of strings with
    identical length.
    The `--target-files` option is now deprecated, since the
    same information can be acquired from the `--tragets`
    introspection API.
  * Meson file rewriter
    This release adds the functionality to perform some basic
    modification on the `meson.build` files from the command
    line. The currently supported operations are:
    + For build targets:
    x Add/Remove source files
    x Add/Remove targets
    x- Modify a select set of kwargs
    x Print some JSON information
    + For dependencies:
    x Modify a select set of kwargs
    + For the project function:
    x Modify a select set of kwargs
    x Modify the default options list
    For more information see the rewriter documentation.
  * `introspect --scan-dependencies` can now be used to scan for
    dependencies used in a project
    It is now possible to run `meson introspect
  - -scan-dependencies
    /path/to/meson.build` without a configured build directory
    to scan for dependencies.
    The output format is as follows:
    ```json
    [
    {
    "name": "The name of the dependency",
    "required": true,
    "conditional": false,
    "has_fallback": false
    }
    ]
    ```
    The `required` keyword specifies whether the dependency is
    marked as required in the `meson.build` (all dependencies are
    required by default). The `conditional` key indicates whether
    the `dependency()` function was called inside a conditional
    block. In a real meson run these dependencies might not be
    used, thus they _may_ not be required, even if the
    `required` key is set. The `has_fallback` key just indicates
    whether a fallback was directly set in the `dependency()`
    function.
  * `introspect --targets` can now be used without configured
    build directory
    It is now possible to run `meson introspect --targets
    /path/to/meson.build` without a configured build directory.
    The generated output is similar to running the introspection
    with a build directory. However, there are some key
    differences:
    + The paths in `filename` now are _relative_ to the future
    build directory
    + The `install_filename` key is completely missing
    + There is only one entry in `target_sources`:
    x With the language set to `unknown`
    x Empty lists for `compiler` and `parameters` and
    `generated_sources`
    x The `sources` list _should_ contain all sources of the
    target
    There is no guarantee that the sources list in
    `target_sources` is correct.
    There might be differences, due to internal limitations. It
    is also not guaranteed that all targets will be listed in
    the output. It might even be possible that targets are
    listed, which won't exist when meson is run normally.
    This can happen if a target is defined inside an if
    statement.
    Use this feature with care.
  * Added option to introspect multiple parameters at once
    Meson introspect can now print the results of multiple
    introspection commands in a single call. The results are
    then printed as a single JSON object.
    The format for a single command was not changed to keep
    backward compatibility.
    Furthermore the option `-a,--all`, `-i,--indent` and
    `-f,--force-object-output` were added to print all
    introspection information in one go,
    format the JSON output (the default is still compact JSON)
    and force use the new output format, even if only one
    introspection command was given.
    A complete introspection dump is also stored in the
    `meson-info` directory. This dump will be (re)generated each
    time meson updates the configuration of the build directory.
    Additionlly the format of `meson introspect target` was
    changed:
    + New: the `sources` key. It stores the source files of a
    target and their compiler parameters.
    + New: the `defined_in` key. It stores the meson file
    where a target is defined
    + New: the `subproject` key. It stores the name of the
    subproject where a target is defined.
    + Added new target types (`jar`, `shared module`).
  * meson configure can now print the default options of an
    unconfigured project
    With this release, it is also possible to get a list of all
    build options by invoking `meson configure` with the project
    source directory or the path to the root `meson.build`. In
    this case, meson will print the default values of all
    options.
  * HDF5
    HDF5 support is added via pkg-config.
  * Added the `meson-info.json` introspection file
    Meson now generates a `meson-info.json` file in the
    `meson-info` directory to provide introspection information
    about the latest meson run. This file is updated when the
    build configuration is changed and the build files are
    (re)generated.
- Refreshed meson-suse-ify-macros.patch
* Tue Feb 26 2019 aloisio@gmx.com
- Update to version 0.49.2
  * qt: Only look for a framework on macOS if building for macOS
  * deps: Don't reject cross usage of extra frameworks
  * pkgconfig: Only warn about deprecation at a location once
  * pkgconfig: Avoid deprecation warning when using new syntax
  * Add all files from scripts to MSI package. Closes #4621.
  * qt: Print the full path of the `qmake` binary found
* Mon Jan 28 2019 dimstar@opensuse.org
- Update to version 0.49.1:
  + dependencies/ui: Don't require lrelease for qt.
  + Better Python exe detector (gh#mesonbuild/meson#4614).
- Drop meson-no-lrelease.patch: fixed upstream.
* Thu Jan 17 2019 tchvatal@suse.com
- Switch to distutils build and properly create egg-info
* Wed Jan 16 2019 dimstar@opensuse.org
- Add meson-no-lrelease.patch: Don't require lrelease for qt.
* Wed Jan  9 2019 tchvatal@suse.com
- Remove succeeding supposed failing gtest test that checks
  gtest version, openSUSE ships the .pc file with the actual
  informations
* Wed Jan  9 2019 tchvatal@suse.com
- Make sure the tests stop on the failure and output the failing
  test at the end for easier digging
* Wed Jan  9 2019 tchvatal@suse.com
- Make the setuptools conditional so I can quickly switch around
  and verify things
* Wed Jan  9 2019 tchvatal@suse.com
- Switch the package to use _multibuild rather than multiple
  spec files
- Require python2-devel for the testsuite (bsc#1125736).
* Tue Jan  8 2019 tchvatal@suse.com
- Use distutils to build/run rather than setuptools to reduce
  buildcycle
- Add patch to be able to build and install using distutils instead
  of full setuptools:
  * meson-distutils.patch
* Tue Dec 11 2018 sor.alexei@meowr.ru
- Update to version 0.49.0:
  * See https://mesonbuild.com/Release-notes-for-0-49-0.html
- Rebase meson-test-installed-bin.patch.
- Rebase meson-suse-fix-llvm-3.8.patch,
  meson-restore-python3.4.patch.
- Add more testsuite dependencies: clang, java-headless,
  mono(csharp), wxWidgets-any-devel.
* Mon Nov 12 2018 sor.alexei@meowr.ru
- Update to version 0.48.2:
  * See https://github.com/mesonbuild/meson/milestone/32?closed=1
* Thu Oct 18 2018 bjorn.lie@gmail.com
- Update to version 0.48.1:
  * See https://github.com/mesonbuild/meson/milestone/31?closed=1
- Drop meson-Fix-handling-generated-desktop-files.patch: Fixed
  upstream.
* Fri Oct  5 2018 bjorn.lie@gmail.com
- Add meson-Fix-handling-generated-desktop-files.patch: Fix
  handling generated .desktop files.
* Mon Oct  1 2018 dimstar@opensuse.org
- Require python3-setuptools.
* Fri Sep 28 2018 sor.alexei@meowr.ru
- Update to version 0.48.0:
  * See http://mesonbuild.com/Release-notes-for-0-48-0.html
- Disable test_generate_gir_with_address_sanitizer with a regex,
  for it fails with ulimits defined in OBS.
- Test against Rust in meson-testsuite on Leap 15.0 or later.
- Rebase meson-suse-ify-macros.patch,
  meson-restore-python3.4.patch, meson-fix-gcc48.patch.
* Sat Aug 25 2018 sor.alexei@meowr.ru
- Update to version 0.47.2:
  * https://github.com/mesonbuild/meson/milestone/29?closed=1
- Rebase meson-restore-python3.4.patch, meson-fix-gcc48.patch.
* Fri Aug  3 2018 sor.alexei@meowr.ru
- Update to version 0.47.1 (bsc#1124324):
  * See https://mesonbuild.com/Release-notes-for-0-47-0.html
- Remove Don-t-raise-StopIteration-in-generators-no-longer-al.patch.
- Add a new dependency for tests:
  libqt5-qtbase-private-headers-devel.
- Set MESON_EXE for tests.
- Adjust meson-test-installed-bin.patch.
- Rebase meson-restore-python3.4.patch, meson-fix-gcc48.patch.
- No longer test with OpenMPI: starting with this release
  "-Wl,--no-undefined -Wl,--as-needed" appears in the gfortran
  arguments, causing an error similiar to lp#1727474.
* Sat Jul 28 2018 bjorn.lie@gmail.com
- Update to version 0.46.1:
  * See https://github.com/mesonbuild/meson/milestone/26?closed=1
- Drop meson-keep-spaces-in-pc-files.patch: Fixed upstream.
* Fri Jul 13 2018 jslaby@suse.com
- Add Don-t-raise-StopIteration-in-generators-no-longer-al.patch
* Sun May 20 2018 dimstar@opensuse.org
- BuildRequire python3-base instead of python3: make building a bit
  cheaper.
* Mon Apr 30 2018 dimstar@opensuse.org
- Add meson-keep-spaces-in-pc-files.patch: Keep spaces in generated
  pkgconfig files (gh#mesonbuild/meson#3479).
- Rebase meson-restore-python3.4.patch.
* Wed Apr 25 2018 sor.alexei@meowr.ru
- Update to version 0.46.0:
  * See http://mesonbuild.com/Release-notes-for-0-46-0.html
- Rebase meson-test-installed-bin.patch,
  meson-restore-python3.4.patch, meson-fix-gcc48.patch.
* Wed Mar 21 2018 sor.alexei@meowr.ru
- Only apply meson-suse-fix-llvm-3.8.patch,
  meson-restore-python3.4.patch, meson-fix-gcc48.patch on Leap 42.x
  or older.
* Wed Mar 21 2018 sor.alexei@meowr.ru
- Fix meson-fix-gcc48.patch.
- Add meson-restore-python3.4.patch: Restore Python 3.4 support for
  SLE 12 and openSUSE Leap 42.x.
- Add meson-suse-fix-llvm-3.8.patch: Fix LLVM 3.8 tests for SLE 12
  and openSUSE Leap 42.x..
* Mon Mar 12 2018 dimstar@opensuse.org
- Add libjpeg-devel BuildRequires to test testsuite.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 0.45.0:
  + Config-Tool based dependencies can be specified in a cross
    file.
  + Visual Studio C# compiler support.
  + Removed two deprecated features:
  - The standalone find_library function has been a no-op for a
    long time. From now on it's an error.
  - There used to be a keywordless version of run_target, which
    is no longer valid.
  + Experimental FPGA support.
  + Generator outputs can preserve directory structure.
  + Hexadecimal string literals.
  + install_data()` defaults to `{datadir}/{projectname}`.
  + install_subdir() supports strip_directory.
  + Integer options.
  + New method meson.project_license().
  + Rust cross-compilation.
  + Rust compiler-private library disambiguation.
  + Project templates.
  + Improve test setup selection.
  + Yielding subproject option to superproject.
- Rebase meson-suse-ify-macros.patch.
* Thu Feb 22 2018 dimstar@opensuse.org
- Update to version 0.44.1:
  + Support running out-of-tree tests against a meson in PATH.
  + Don't add rpaths to system libraries.
  + Fix meson location detection from other meson tools.
  + Various boost, pkg-config and vala related fixes.
- Testsuite changes: Remove mesonbuild directory and meson.py
  again before running the test: ensure we test meson as it was
  installed onto the system.
* Mon Feb  5 2018 dimstar@opensuse.org
- Update to version 0.44.0:
  + New features:
  - Added warning function.
  - Adds support for additional Qt5-Module keyword
    moc_extra_arguments.
  - Prefix-dependent defaults for sysconfdir, localstatedir and
    sharedstatedir.
  - An array type for user options.
  - LLVM dependency supports both dynamic and static linking.
  - Added if_found to subdir.
  - get_unquoted() method for the configuration data object.
  - Added disabler object.
  - Config-Tool based dependencies gained a method to get
    arbitrary options.
  - Embedded Python in Windows MSI packages.
- Rebase meson-suse-ify-macros.patch, meson-fix-gcc48.patch and
  meson-test-installed-bin.patch.
- Testsuite changes:
  + Disable tests for static llvm: we don't ship the static libs.
  + Add cmake(Qt5LinguistTools), libwmf-devel BuildRequires and
    zlib-devel-static: new dependencies for various tests.
* Wed Nov 22 2017 sor.alexei@meowr.ru
- Require python3-xml: mesonbuild/modules/qt5.py imports the xml
  module (boo#1068818).
* Mon Oct 23 2017 dimstar@opensuse.org
- Setup MPI runtime environment before running the test suite.
- Remove tests for static boost libraries from
  test\ cases/frameworks/1\ boost/meson.build.
* Thu Oct 19 2017 badshah400@gmail.com
- Update to version 0.43.0:
  + Generator learned capture: Generators can now be configured to
    capture the standard output.
  + Can index CustomTarget objects: The CustomTarget object can
    now be indexed like an array. The resulting object can be used
    as a source file for other Targets, this will create a
    dependency on the original CustomTarget, but will only insert
    the generated file corresponding to the index value of the
    CustomTarget's output keyword.
  + The cross file can now be used for overriding the result of
    find_program. Then issuing the command find_program('objdump')
    will return the version specified in the cross file.
  + Easier handling of supported compiler arguments.
  + Better support for shared libraries in non-system paths: This
    release adds feature parity to shared libraries that are
    either in non-standard system paths or shipped as part of your
    project. On systems that support rpath, Meson automatically
    adds rpath entries to built targets using manually found
    external libraries.
  + The Wrap dependency system now supports Subversion (svn). This
    support is rudimentary. The repository url has to point to a
    specific (sub)directory containing the meson.build file
    (typically trunk/). However, providing a revision is
    supported.
- Rebase meson-test-installed-bin.patch.
- Run sed to strip the hashbang from a non-executable file; this
  prevents an rpmlint warning.
* Wed Oct 11 2017 sor.alexei@meowr.ru
- Don't use obsolete boost-devel for openSUSE Leap 15.0 and newer
  (boo#1062785).
* Mon Oct  2 2017 jdelvare@suse.com
- Update to version 0.42.1. This is a stable update with various
  bug fixes.
* Fri Sep  8 2017 sor.alexei@meowr.ru
- Rebase meson-fix-gcc48.patch (boo#1057701).
* Tue Aug 15 2017 dimstar@opensuse.org
- Extend meson-test-installed-bin.patch: catch some more cases
  where the test suite referenced meson.py from the source
  directory.
- Add vulkan-devel and libpcap-devel BuildRequires for the test
  suite: new dependencies.
* Tue Aug 15 2017 zaitor@opensuse.org
- Update to version 0.42.0:
  + Distribution tarballs from Mercurial repositories. Creating
    distribution tarballs can now be made out of projects based on
    Mercurial. As before, this remains possible only with the Ninja
    backend.
  + Keyword argument verification. Meson will now check the keyword
    arguments used when calling any function and print a warning if
    any of the keyword arguments is not known. In the future this
    will become a hard error.
  + Add support for Genie to Vala compiler. The Vala compiler has
    an alternative syntax, Genie, that uses the .gs file extension.
    Meson now recognises and uses Genie files.
  + Pkgconfig support for additional cflags. The Pkgconfig module
    object can add arbitrary extra cflags to the Cflags value in
    the .pc file, using the "extra_cflags" keyword.
  + Base options accessible via get_option(). Base options are now
    accessible via the get_option() function.
  + Allow crate type configuration for Rust compiler. Rust targets
    now take an optional rust_crate_type keyword, allowing you to
    set the crate type of the resulting artifact. Valid crate types
    are dylib or cdylib for shared libraries, and rlib or staticlib
    for static libraries. For more, see Rust's linkage reference.
  + Simultaneous use of Address- and Undefined Behavior Sanitizers.
    Both the address- and undefined behavior sanitizers can now be
    used simultaneously by passing -Db_sanitize=address,undefined
    to Meson.
  + Unstable SIMD module. A new experimental module to compile code
    with many different SIMD instruction sets and selecting the
    best one at runtime. This module is unstable, meaning it's API
    is subject to change in later releases. It might also be
    removed altogether.
  + Import libraries for executables on Windows. The new keyword
    implib to executable() allows generation of an import library
    for the executable.
  + Added build_rpath keyword argument. You can specify
    build_rpath: '/foo/bar' in build targets and the given path
    will get added to the target's rpath in the build tree. It is
    removed during the install step.
  + Meson will print a warning when the user tries to add an rpath
    linker flag manually, e.g. via link_args to a target. This is
    not recommended because having multiple rpath causes them to
    stomp on each other. This warning will become a hard error in
    some future release.
  + Vulkan dependency module. Vulkan can now be used as native
    dependency. The dependency module will detect the VULKAN_SDK
    environment variable or otherwise try to receive the vulkan
    library and header via pkgconfig or from the system.
  + Limiting the maximum number of linker processes. With the Ninja
    backend it is now possible to limit the maximum number of
    concurrent linker processes. This is usually only needed for
    projects that have many large link steps that cause the system
    to run out of memory if they are run in parallel. This limit
    can be set with the new backend_max_links option.
  + Disable implicit include directories. By default Meson adds the
    current source and build directories to the header search path.
    On some rare occasions this is not desired. Setting the
    implicit_include_directories keyword argument to false these
    directories are not used.
  + Support for MPI dependency. MPI is now supported as a
    dependency. Because dependencies are language-specific, you
    must specify the requested language with the language keyword,
    i.e., dependency('mpi', language='c') will request the C MPI
    headers and libraries. See the MPI dependency for more
    information.
  + Allow excluding files or directories from install_subdir. The
    install_subdir command accepts the new exclude_files and
    exclude_directories keyword arguments that allow specified
    files or directories to be excluded from the installed
    subdirectory.
  + Make all Meson functionality invokable via the main executable.
    Previously Meson had multiple executables such as
    mesonintrospect and mesontest. They are now invokable via the
    main Meson executable like this: meson configure <arguments> #
    equivalent to mesonconf <options> meson test <arguments> #
    equivalent to mesontest <arguments> The old commands are still
    available but they are deprecated and will be removed in some
    future release.
  + Pcap dependency detector. Meson will automatically obtain
    dependency information for pcap using the pcap-config tool. It
    is used like any other dependency.
  + GNOME module mkenums_simple() addition. Most libraries and
    applications use the same standard templates for glib-mkenums.
    There is now a new mkenums_simple() convenience  method that
    passes those default templates to glib-mkenums and allows some
    tweaks such as optional function decorators or leading
    underscores.
- Rebase meson-fix-gcc48.patch and meson-test-installed-bin.patch.
* Sat Jul 22 2017 mailaender@opensuse.org
- Update to version 0.41.2:
  + Various gtkdoc fixes.
  + Fix how rpath directories are handled.
  + pkgconfig: avoid appending slash at Cflags.
  + Fix a missing path issue causing Python traceback.
  + Qt4 support.
  + Skip handling non-available dependencies.
  + vala: Only add --use-header for unity builds regression.
  + Tag functions in asm properly.
* Tue Jun 27 2017 rodrigo.z.lourenco@tecnico.ulisboa.pt
- Add a vim subpackage to add Meson support to Vim.
* Fri Jun 23 2017 dimstar@opensuse.org
- Split testsuite into an own package, in order to keep the build
  dep chain of meson minimal.
- Drop meson-disable-untested-code.patch: no longer required.
- Add meson-test-installed-bin.patch: use /usr/bin/meson instead of
  meson.py from the source tarball. We want to test the meson
  binary package we produced, not the sources directly.
* Fri Jun 23 2017 dimstar@opensuse.org
- Update to version 0.41.1:
  + wxwidgets: Fix usage of multiple dependency() calls.
  + Make external library no-op when used with incompatible
    target (gh#mesonbuild/meson#1941).
  + Failing test for -D dedupping.
  + Preserve standalone -D arguments always.
  + Handle both pkg-config and pkgconf argument order
    (gh#mesonbuild/meson#1934).
* Fri Jun 23 2017 dimstar@opensuse.org
- Update meson-suse-ify-macros.patch: export LANG for all macros.
* Mon Jun 19 2017 rpm@fthiessen.de
- Update to version 0.41.0:
  * Native support for linking against LLVM using
    the dependency function.
  * Pkgconfig support for custom variables.
  * A target for creating tarballs using 'ninja dist'.
  * Support for passing arguments to Rust compiler.
  * All known issues regarding reproducible builds are fixed.
  * Extended template substitution in configure_file
    for @BASENAME@ and @PLAINNAME@ .
  * Support for capturing stdout of a command in configure_file.
- Removed SDL2 test to reduce dependencies (smaller build footprint)
- Dropped upstreamed patch meson-handle-skipped-tests.patch
- Rebased meson-suse-ify-macros.patch and meson-fix-gcc48.patch
* Tue Jun  6 2017 dimstar@opensuse.org
- Make the build footprint smaller to enter ring1: This means we
  skip a couple tests though. Removed BuildRequires: java-devel,
  libqt5-qtbase-devel, mono-core, mono-devel, wxWidgets-devel,
  pkgconfig(protobuf) and pkgconfig(gtk+-3.0).
* Wed May 17 2017 dimstar@opensuse.org
- Add meson-handle-skipped-tests.patch: Actually do skip tests that
  are marked as MESON_SKIP_TEST (gh#mesonbuild/meson#1804).
* Mon May  8 2017 dimstar@opensuse.org
- Update to version 0.40.1:
  + Outputs of generators can be used in custom targets in the VS
    backend.
  + Visual Studio 2017 support.
  + Automatic initialization of subprojects that are git
    submodules.
  + No download mode for wraps.
  + Overriding options per target.
  + Compiler object get define.
  + Cygwin support.
  + Multiple install directories.
  + Can specify method of obtaining dependencies.
  + Link whole contents of static libraries.
  + Unity builds only for subprojects.
  + Running mesonintrospect from scripts.
* Mon Mar 20 2017 dimstar@opensuse.org
- Add meson-disable-untested-code.patch: meson has code in the test
  suite that assumes different behaviour between glib 2.51.5 (rc)
  and 2.52.0 (final); this must be a wrong assumption to start with
  and the test suite fails with 2.52.0. When this was added by
  upstream 4 months before glib-2.52.0 was released, there must
  have been no way at all to test this. We revert back to a state
  like with the previous glib verison, where this test was simply
  skipped (gh#mesonbuild/meson#1480).
* Thu Mar 16 2017 sor.alexei@meowr.ru
- Update to version 0.39.1 (changes since 0.38.1):
  * Allow specifying extra arguments for tests.
  * Bug fixes and minor polishes.
- Add meson-fix-gcc48.patch: fix GCC 4.8 handling for
  openSUSE Leap 42.x.
* Sat Mar  4 2017 dimstar@opensuse.org
- Update to version 0.38.1:
  + New Uninstall target.
  + Support for arbitrary test setups.
  + Intel C/C++ compiler support.
  + Get values from configuration data objects.
  + Python 3 module support simplified.
  + Default options to subprojects.
  + Set targets to be built (or not) by default.
  + Add option to mesonconf to wipe cached data.
  + Can specify file permissions and owner when installing data.
  + has_header() checks are now faster.
  + Array indexing now supports fallback values.
  + Silent mode for Mesontest.
- Rebase meson-suse-ify-macros.patch.
* Tue Jan 10 2017 dimstar@opensuse.org
- Add meson-suse-ify-macros.patch: Make the meson macros also work
  on openSUSE. We do not (yet?) have separate macros for CFLAGS,
  CXXFLAGS, FFLAGS and LDFLAGS, but only carry optflags. This is no
  issue, since openSUSE so far only added flags that work accross
  compilers/languages. This might change in the future, making the
  patch obsolete.
* Sun Jan  1 2017 sor.alexei@meowr.ru
- Update to version 0.37.1:
  * No changelog available.
* Sun Jan  1 2017 jengelh@inai.de
- Trim boasting words from descriptions. Add to description two
  points from the feature list.
* Mon Dec 19 2016 dev@antergos.com
- Update to version 0.37.0:
  * Mesontest: a new testing tool that allows you to run your
    tests in many different ways.
  * New shared_module function allows shared modules creation.
  * GNOME module now detects required programs and prints useful
    errors if any are missing.
  * GNOME module uses depfile support available in GLib >= 2.52.0.
  * i18n module has a new merge_file() function for creating
    translated files.
  * LLVM IR compilation is now supported.
  * .wrap files for subprojects can now include a separate push
    URL to allow developers to push changes directly from a
    subproject git checkout.
  * Multiple version restrictions while searching for pkg-config
    dependencies is now supported.
  * Support for localstatedir has been added.
  * You can now pass arguments to install scripts added with
    meson.add_install_script().
  * Added new options sbindir and infodir that can be used for
    installation.
- Remove meson-0.36.0-fix-old-pkgconfig-test.patch.
* Sat Dec 10 2016 sor.alexei@meowr.ru
- Add meson-0.36.0-fix-old-pkgconfig-test.patch: tests/common/51:
  Skip validate if pkg-config is too old (commit 2f804e9).
* Tue Nov 22 2016 dimstar@opensuse.org
- Update to version 0.36.0:
  + Add option to run under gdb.
  + Always specify installed data with a File object
    (gh#mesonbuild/meson#858).
  + Made has_function survive optimization flags
    (gh#mesonbuild/meson#1053).
  + Can give many alternative names to find_program to simplify
    searching.
  + Can set compiler arguments in Java.
- Export SUSE_ASNEEDED=0 when running the test suite: linking the
  test libraries/binaries is not done optimally.
* Tue Oct 18 2016 sor.alexei@meowr.ru
- Update to version 0.35.1:
  * No changelog available.
* Fri Oct 14 2016 zaitor@opensuse.org
- Update to version 0.35.0:
  + No changelog available from upstream.
- Changes from version 0.34.0:
  + No changelog available from upstream.
- Drop meson-633.patch and meson-typelib-install.patch : Fixed
  upstream.
* Wed Aug 17 2016 dimstar@opensuse.org
- Update to version 0.33.0:
  + Correctly install .typelib files to libdir.
  + Add option for as-needed link option.
  + Print the CFLAGS/LDFLAGS/etc inherited from the environment.
  + Only append compile flags to the link flags when appropriate.
- Add meson-633.patch: Handle both DT_RPATH as well as DT_RUNPATH
  when fixing rpath settings (gh#mesonbuild/meson#663).
- Add meson-typelib-install.patch: Fix installation path for
  gpobject introspection typelib files.
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 0.32.0:
  * No changelog available.
- Remove meson-gui package: GUI was removed upstream.
* Mon May  9 2016 jengelh@inai.de
- Avoid unnecessary bashism in %%install script (run with /bin/sh)
* Sat May  7 2016 sor.alexei@meowr.ru
- Update to version 0.31.0.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 0.29.0.
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 0.28.0.
* Fri Dec  4 2015 sor.alexei@meowr.ru
- Update to 0.27.0.
* Sun Sep 13 2015 sor.alexei@meowr.ru
- Update to 0.26.0.
- Use signed tarball.
* Sun Jul 12 2015 sor.alexei@meowr.ru
- Initial package based on the work of Igor Gnatenko.
